import { SvelteComponentTyped } from "svelte";
declare const __propDef: {
    props: {
        /**
             * Code to be shown.
             *
             * Note: This value is changed from inside of this component. By default, you won't be able to detect changes.
             * But if you use it as `bind:value`, all changeswill flow back to the component where yur using `SimpleCodeEditor`.
             *
             * @default ''
             *
             * @example
             * ```svelte
             * <SimpleCodeEditor value="var num = 10;" />
             *
             * <!-- Update local variable `value` as user types into the editor -->
             * <SimpleCodeEditor bind:value={value} />
             * ```
             */ value: string;
        /**
             * Highlight function. takes a string and returns a string(the highlighted code).
             *
             * @default () => ''
             *
             * @example
             * ```svelte
             * <SimpleCodeEditor highlight={(code) => Prism.highlight(code, Prism.languages.javascript, 'javascript').value} />
             * ```
             */ highlight?: (value: string) => string;
        /**
             * Insert spaces instead of tabs.
             *
             * @default true
             *
             * @example
             * ```svelte
             * <SimpleCodeEditor insertSpaces={false} />
             * ```
             */ insertSpaces?: boolean;
        /**
             * Tab size. When you hit Tab key, how much indentation should be added.
             *
             * @default 2
             *
             * @example
             * ```svelte
             * <SimpleCodeEditor tabSize={4} />
             * ```
             */ tabSize?: number;
        /**
             * When you hit tab, should it add indentation or focus out of the editor
             *
             * @default false
             *
             * @example
             * ```svelte
             * <SimpleCodeEditor ignoreTabKey={true} />
             * ```
             */ ignoreTabKey?: boolean;
        /**
             * Class to apply to pre tag used internally. This is necessary when using custom themes with PrismJS and you have to give your `<pre>` tag a class like `language-`.
             *
             * @default ''
             *
             * @example
             * ```svelte
             * <SimpleCodeEditor preClass="language-javascript" />
             * ```
             */ preClass?: string;
        /**
             * Attributes to pass to the internal `<textarea>` tag.
             *
             * @default {}
             *
             * @example
             * ```svelte
             * <SimpleCodeEditor textAreaProps={{ spellcheck: false }} />
             * ```
             */ textAreaProps?: Omit<svelte.JSX.HTMLAttributes<HTMLTextAreaElement>, keyof svelte.JSX.DOMAttributes<HTMLTextAreaElement> | 'value' | 'class' | 'autocapitalize' | 'autocomplete' | 'autocorrect' | 'autofocus'>;
    };
    events: {
        'value-change': CustomEvent<string>;
        keydown: CustomEvent<KeyboardEvent>;
    } & {
        [evt: string]: CustomEvent<any>;
    };
    slots: {};
};
export declare type EditorProps = typeof __propDef.props;
export declare type EditorEvents = typeof __propDef.events;
export declare type EditorSlots = typeof __propDef.slots;
/** --padding: sets padding on the textarea */
export default class Editor extends SvelteComponentTyped<EditorProps, EditorEvents, EditorSlots> {
}
export {};
